/*******************************************************************************
* File Name: Clipping_Sense.h  
* Version 1.80
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the Analog Comparator User Module.
*
*  Note:
*     
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_COMP_Clipping_Sense_H) 
#define CY_COMP_Clipping_Sense_H

#include "cytypes.h"
#include "CyLib.h"
#include "cyfitter.h" 

#define Clipping_Sense_RECALMODE 0u


/***************************************
*       Type defines
***************************************/

/* Sleep Mode API Support */
typedef struct Clipping_Sense_backupStruct
{
    uint8 enableState;
    uint8 compCRReg;
}Clipping_Sense_backupStruct;


/**************************************
*        Function Prototypes 
**************************************/

void    Clipping_Sense_Start(void);
void    Clipping_Sense_Stop(void)               ;
void    Clipping_Sense_SetSpeed(uint8 speed)    ;
uint8   Clipping_Sense_GetCompare(void)         ;
uint16  Clipping_Sense_ZeroCal(void)            ;
void    Clipping_Sense_LoadTrim(uint16 trimVal) ;
void Clipping_Sense_Init(void)                  ; 
void Clipping_Sense_Enable(void)                ;
void Clipping_Sense_SaveConfig(void);
void Clipping_Sense_RestoreConfig(void);
void Clipping_Sense_Sleep(void);
void Clipping_Sense_Wakeup(void)                ;
/* Below APIs are valid only for PSoC3 silicon.*/
#if (CY_PSOC3) 
    void Clipping_Sense_PwrDwnOverrideEnable(void) ;
    void Clipping_Sense_PwrDwnOverrideDisable(void) ;
#endif /* CY_PSOC3 */


/**************************************
*           API Constants        
**************************************/

/* Power constants for SetSpeed() function */
#define Clipping_Sense_SLOWSPEED   0x00u
#define Clipping_Sense_HIGHSPEED   0x01u
#define Clipping_Sense_LOWPOWER    0x02u


/***************************************
*         Trim Locations               
****************************************/

/* High speed trim values */
#define Clipping_Sense_HS_TRIM_TR0        (CY_GET_XTND_REG8(Clipping_Sense_ctComp__TRIM__TR0_HS))

#if (CY_PSOC3_ES3 || CY_PSOC5_ES2)
    #define Clipping_Sense_HS_TRIM_TR1    (CY_GET_XTND_REG8(Clipping_Sense_ctComp__TRIM__TR1_HS))
#endif /* (CY_PSOC3_ES3 || CY_PSOC5_ES2) */

/* Low speed trim values */
#define Clipping_Sense_LS_TRIM_TR0        (CY_GET_XTND_REG8(Clipping_Sense_ctComp__TRIM__TR0 + 1))

#if (CY_PSOC3_ES3 || CY_PSOC5_ES2)
    #define Clipping_Sense_LS_TRIM_TR1    (CY_GET_XTND_REG8(Clipping_Sense_ctComp__TRIM__TR1 + 1))
#endif /* CY_PSOC3_ES3 || CY_PSOC5_ES2 */


/**************************************
*           Parameter Defaults        
**************************************/

#define Clipping_Sense_DEFAULT_SPEED       1u 
#define Clipping_Sense_DEFAULT_HYSTERESIS  1u
#define Clipping_Sense_DEFAULT_POLARITY    1u
#define Clipping_Sense_DEFAULT_BYPASS_SYNC 0u
#define Clipping_Sense_DEFAULT_PWRDWN_OVRD 0u


/**************************************
*             Registers        
**************************************/

#define Clipping_Sense_CR      (* (reg8 *) Clipping_Sense_ctComp__CR )   /* Config register   */
#define Clipping_Sense_CR_PTR  (  (reg8 *) Clipping_Sense_ctComp__CR )
#define Clipping_Sense_CLK     (* (reg8 *) Clipping_Sense_ctComp__CLK )  /* Comp clock control register */
#define Clipping_Sense_CLK_PTR (  (reg8 *) Clipping_Sense_ctComp__CLK )
#define Clipping_Sense_SW0     (* (reg8 *) Clipping_Sense_ctComp__SW0 )  /* Routing registers */
#define Clipping_Sense_SW0_PTR (  (reg8 *) Clipping_Sense_ctComp__SW0 )
#define Clipping_Sense_SW2     (* (reg8 *) Clipping_Sense_ctComp__SW2 )
#define Clipping_Sense_SW2_PTR (  (reg8 *) Clipping_Sense_ctComp__SW2 )
#define Clipping_Sense_SW3     (* (reg8 *) Clipping_Sense_ctComp__SW3 )
#define Clipping_Sense_SW3_PTR (  (reg8 *) Clipping_Sense_ctComp__SW3 )
#define Clipping_Sense_SW4     (* (reg8 *) Clipping_Sense_ctComp__SW4 )
#define Clipping_Sense_SW4_PTR (  (reg8 *) Clipping_Sense_ctComp__SW4 )
#define Clipping_Sense_SW6     (* (reg8 *) Clipping_Sense_ctComp__SW6 )
#define Clipping_Sense_SW6_PTR (  (reg8 *) Clipping_Sense_ctComp__SW6 )

/* Trim registers */
/* PSoC3 ES2 or early, PSoC5 ES1 or early */
#if (CY_PSOC3_ES2 || CY_PSOC5_ES1)
    #define Clipping_Sense_TR      (* (reg8 *) Clipping_Sense_ctComp__TR )   /* Trim registers */
    #define Clipping_Sense_TR_PTR  (  (reg8 *) Clipping_Sense_ctComp__TR )
#endif /* CY_PSOC3_ES2 || CY_PSOC5_ES1 */

/* PSoC3 ES3 or later, PSoC5 ES2 or later */
#if (CY_PSOC3_ES3 || CY_PSOC5_ES2) 
    #define Clipping_Sense_TR0         (* (reg8 *) Clipping_Sense_ctComp__TR0 ) /* Trim register for P-type load */
    #define Clipping_Sense_TR0_PTR     (  (reg8 *) Clipping_Sense_ctComp__TR0 ) 
    #define Clipping_Sense_TR1         (* (reg8 *) Clipping_Sense_ctComp__TR1 ) /* Trim register for N-type load */
    #define Clipping_Sense_TR1_PTR     (  (reg8 *) Clipping_Sense_ctComp__TR1 ) 
#endif /* CY_PSOC3_ES3 || CY_PSOC5_ES2 */

#define Clipping_Sense_WRK             (* (reg8 *) Clipping_Sense_ctComp__WRK )  /* Working register - output */
#define Clipping_Sense_WRK_PTR         (  (reg8 *) Clipping_Sense_ctComp__WRK )
#define Clipping_Sense_PWRMGR          (* (reg8 *) Clipping_Sense_ctComp__PM_ACT_CFG )  /* Active Power manager */
#define Clipping_Sense_PWRMGR_PTR      ( (reg8 *) Clipping_Sense_ctComp__PM_ACT_CFG )
#define Clipping_Sense_STBY_PWRMGR     (* (reg8 *) Clipping_Sense_ctComp__PM_STBY_CFG )  /* Standby Power manager */
#define Clipping_Sense_STBY_PWRMGR_PTR ( (reg8 *) Clipping_Sense_ctComp__PM_STBY_CFG )


/**************************************
*       Register Constants        
**************************************/

/* CR (Comp Control Register)             */
#define Clipping_Sense_CFG_MODE_MASK  0x78u
#define Clipping_Sense_FILTER_ON      0x40u
#define Clipping_Sense_HYST_OFF       0x20u
#define Clipping_Sense_CAL_ON         0x10u
#define Clipping_Sense_MX_AO          0x08u
#define Clipping_Sense_PWRDWN_OVRD    0x04u

#define Clipping_Sense_PWR_MODE_SHIFT 0x00u
#define Clipping_Sense_PWR_MODE_MASK  (0x03u << Clipping_Sense_PWR_MODE_SHIFT)
#define Clipping_Sense_PWR_MODE_SLOW  (0x00u << Clipping_Sense_PWR_MODE_SHIFT)
#define Clipping_Sense_PWR_MODE_FAST  (0x01u << Clipping_Sense_PWR_MODE_SHIFT)
#define Clipping_Sense_PWR_MODE_ULOW  (0x02u << Clipping_Sense_PWR_MODE_SHIFT)

/* CLK (Comp Clock Control Register)      */
#define Clipping_Sense_BYPASS_SYNC    0x10u
#define Clipping_Sense_SYNC_CLK_EN    0x08u
#define Clipping_Sense_SYNCCLK_MASK   (Clipping_Sense_BYPASS_SYNC | Clipping_Sense_SYNC_CLK_EN)

/* SW3 Routing Register definitions */
#define Clipping_Sense_CMP_SW3_INPCTL_MASK    0x09u   /* SW3 bits for inP routing control */

/* TR (Comp Trim Register)     */
#define Clipping_Sense_DEFAULT_CMP_TRIM  0x00u

/* PSoC3 ES2 or early, PSoC5 ES1 or early */
#if (CY_PSOC3_ES2 || CY_PSOC5_ES1)
    #define Clipping_Sense_CMP_TRIM1_DIR  0x08u   /* Trim direction for N-type load for offset calibration */
    #define Clipping_Sense_CMP_TRIM1_MASK 0x07u   /* Trim for N-type load for offset calibration */
    #define Clipping_Sense_CMP_TRIM2_DIR  0x80u   /* Trim direction for P-type load for offset calibration */
    #define Clipping_Sense_CMP_TRIM2_MASK 0x70u   /* Trim for P-type load for offset calibration */
#endif /* CY_PSOC3_ES2 || CY_PSOC5_ES1 */

/* PSoC3 ES3 or later, PSoC5 ES2 or later */
#if (CY_PSOC3_ES3 || CY_PSOC5_ES2)
    #define Clipping_Sense_CMP_TR0_DIR 0x11u    /* Trim direction for N-type load for offset calibration */
    #define Clipping_Sense_CMP_TR0_MASK 0x1Fu   /* Trim for N-type load for offset calibration */
    #define Clipping_Sense_CMP_TR1_DIR 0x10u    /* Trim direction for P-type load for offset calibration */
    #define Clipping_Sense_CMP_TR1_MASK 0x1Fu   /* Trim for P-type load for offset calibration */ 
#endif /* CY_PSOC3_ES3 || CY_PSOC5_ES2 */


/* WRK (Comp output working register)     */ 
#define Clipping_Sense_CMP_OUT_MASK   Clipping_Sense_ctComp__WRK_MASK /* Specific comparator out mask */

/* PM_ACT_CFG7 (Active Power Mode CFG Register)     */ 
#define Clipping_Sense_ACT_PWR_EN     Clipping_Sense_ctComp__PM_ACT_MSK /* Power enable mask */

/* PM_STBY_CFG7 (Standby Power Mode CFG Register)     */ 
#define Clipping_Sense_STBY_PWR_EN     Clipping_Sense_ctComp__PM_STBY_MSK /* Standby Power enable mask */

#if (CY_PSOC5_ES1)
    /* For stop API changes mask to make the COMP register CR to 0X00  */
    #define Clipping_Sense_COMP_REG_CLR             (0x00u)
#endif /* CY_PSOC5_ES1 */

#endif /* CY_COMP_Clipping_Sense_H */


/* [] END OF FILE */
