/*******************************************************************************
* File Name: Divider.h  
* Version 2.10
*
* Description:
*  Contains the prototypes and constants for the functions available to the 
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

#if !defined(CY_PWM_Divider_H)
#define CY_PWM_Divider_H


/***************************************
* Conditional Compilation Parameters
***************************************/
#define Divider_Resolution 16u
#define Divider_UsingFixedFunction 1u
#define Divider_DeadBandMode 0u
#define Divider_KillModeMinTime 0u
#define Divider_KillMode 1u
#define Divider_PWMMode 0u
#define Divider_PWMModeIsCenterAligned 0u
#define Divider_DeadBandUsed 0u
#define Divider_DeadBand2_4 0u
#if !defined(Divider_PWMUDB_sSTSReg_stsreg__REMOVED)
    #define Divider_UseStatus 1u
#else
    #define Divider_UseStatus 0u
#endif
#if !defined(Divider_PWMUDB_sCTRLReg_ctrlreg__REMOVED)
    #define Divider_UseControl 1u
#else
    #define Divider_UseControl 0u
#endif
#define Divider_UseOneCompareMode 1u
#define Divider_MinimumKillTime 1u
#define Divider_EnableMode 0u

#define Divider_CompareMode1SW 0u
#define Divider_CompareMode2SW 0u

/* PSoC3 ES2 or early */
#define Divider_PSOC3_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)   && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))

/* PSoC5 ES1 or early */
#define Divider_PSOC5_ES1   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)   && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))

/* PSoC3 ES3 or later */
#define Divider_PSOC3_ES3   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                     (CYDEV_CHIP_REVISION_USED >= CYDEV_CHIP_REVISION_3A_ES3))

/* PSoC5 ES2 or later */
#define Divider_PSOC5_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)   && \
                                     (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))

/* Use Kill Mode Enumerated Types */
#define Divider__B_PWM__DISABLED 0
#define Divider__B_PWM__ASYNCHRONOUS 1
#define Divider__B_PWM__SINGLECYCLE 2
#define Divider__B_PWM__LATCHED 3
#define Divider__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define Divider__B_PWM__DBMDISABLED 0
#define Divider__B_PWM__DBM_2_4_CLOCKS 1
#define Divider__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define Divider__B_PWM__ONE_OUTPUT 0
#define Divider__B_PWM__TWO_OUTPUTS 1
#define Divider__B_PWM__DUAL_EDGE 2
#define Divider__B_PWM__CENTER_ALIGN 3
#define Divider__B_PWM__DITHER 5
#define Divider__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define Divider__B_PWM__LESS_THAN 1
#define Divider__B_PWM__LESS_THAN_OR_EQUAL 2
#define Divider__B_PWM__GREATER_THAN 3
#define Divider__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define Divider__B_PWM__EQUAL 0
#define Divider__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/

/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct Divider_backupStruct
{
    
    uint8 PWMEnableState;
       
    #if(!Divider_UsingFixedFunction)
        #if (Divider_PSOC3_ES2 || Divider_PSOC5_ES1)
            uint16 PWMUdb;               /* PWM Current Counter value  */
            uint16 PWMPeriod;            /* PWM Current Period value   */
            #if (Divider_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif
            #if(Divider_UseOneCompareMode)
                uint16 PWMCompareValue;     /* PWM Current Compare value */
            #else
                uint16 PWMCompareValue1;     /* PWM Current Compare value1 */
                uint16 PWMCompareValue2;     /* PWM Current Compare value2 */
            #endif
            
            /* Backup for Deadband parameters */
            #if(Divider_DeadBandMode == Divider__B_PWM__DBM_256_CLOCKS || Divider_DeadBandMode == Divider__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif
            
            /* Backup Kill Mode Counter*/
            #if(Divider_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif
            
        #endif
        
        #if (Divider_PSOC3_ES3 || Divider_PSOC5_ES2)
            uint16 PWMUdb;               /* PWM Current Counter value  */
            #if(!Divider_PWMModeIsCenterAligned)
                uint16 PWMPeriod;
            #endif
            #if (Divider_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif
            
            /* Backup for Deadband parameters */
            #if(Divider_DeadBandMode == Divider__B_PWM__DBM_256_CLOCKS || Divider_DeadBandMode == Divider__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif
            
            /* Backup Kill Mode Counter*/
            #if(Divider_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif
        #endif
        
        
        /* Backup control register */
        #if(Divider_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif
        
    #endif 
   
}Divider_backupStruct;

/***************************************
*        Function Prototypes
 **************************************/
 
void    Divider_Start(void);
void    Divider_Stop(void) ;
#if (Divider_UseStatus || Divider_UsingFixedFunction)
    #define Divider_SetInterruptMode(interruptMode) CY_SET_REG8(Divider_STATUS_MASK_PTR, interruptMode)
    #define Divider_ReadStatusRegister() CY_GET_REG8(Divider_STATUS_PTR)
#endif
#define Divider_GetInterruptSource() Divider_ReadStatusRegister()
#if (Divider_UseControl)
    #define Divider_ReadControlRegister() CY_GET_REG8(Divider_CONTROL_PTR) 
    #define Divider_WriteControlRegister(control) CY_SET_REG8(Divider_CONTROL_PTR, control)
#endif
#if (Divider_UseOneCompareMode)
   #if (Divider_CompareMode1SW)
       void    Divider_SetCompareMode(uint8 comparemode) ;
   #endif
#else
    #if (Divider_CompareMode1SW)
        void    Divider_SetCompareMode1(uint8 comparemode) ;
    #endif
    #if (Divider_CompareMode2SW)
        void    Divider_SetCompareMode2(uint8 comparemode) ;
    #endif
#endif

#if (!Divider_UsingFixedFunction)
    uint16   Divider_ReadCounter(void) ;
    #define Divider_ReadCapture() CY_GET_REG16(Divider_CAPTURE_LSB_PTR)
    #if (Divider_UseStatus)
        void Divider_ClearFIFO(void) ;
    #endif
#endif

void    Divider_WriteCounter(uint16 counter) ;
void    Divider_WritePeriod(uint16 period) ;
#define Divider_ReadPeriod() CY_GET_REG16(Divider_PERIOD_LSB_PTR) 
#if (Divider_UseOneCompareMode)
    void    Divider_WriteCompare(uint16 compare) ;
    #define Divider_ReadCompare() CY_GET_REG16(Divider_COMPARE1_LSB_PTR) 
#else
    void    Divider_WriteCompare1(uint16 compare) ;
    #define Divider_ReadCompare1() CY_GET_REG16(Divider_COMPARE1_LSB_PTR) 
    void    Divider_WriteCompare2(uint16 compare) ;
    #define Divider_ReadCompare2() CY_GET_REG16(Divider_COMPARE2_LSB_PTR) 
#endif


#if (Divider_DeadBandUsed)
    void    Divider_WriteDeadTime(uint8 deadtime) ;
    uint8   Divider_ReadDeadTime(void) ;
#endif

#if ( Divider_KillModeMinTime)
    #define Divider_WriteKillTime(killtime) CY_SET_REG8(Divider_KILLMODEMINTIME_PTR, killtime) 
    #define Divider_ReadKillTime() CY_GET_REG8(Divider_KILLMODEMINTIME_PTR) 
#endif

void Divider_Init(void) ;
void Divider_Enable(void) ;
void Divider_Sleep(void);
void Divider_Wakeup(void) ;
void Divider_SaveConfig(void);
void Divider_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define Divider_INIT_PERIOD_VALUE        1u
#define Divider_INIT_COMPARE_VALUE1      1u
#define Divider_INIT_COMPARE_VALUE2      63u
#define Divider_INIT_INTERRUPTS_MODE     ((0u << Divider_STATUS_TC_INT_EN_MASK_SHIFT) | (0 << Divider_STATUS_CMP2_INT_EN_MASK_SHIFT) | (0 << Divider_STATUS_CMP1_INT_EN_MASK_SHIFT ) | (0 << Divider_STATUS_KILL_INT_EN_MASK_SHIFT ))
#define Divider_DEFAULT_COMPARE2_MODE    (1u << Divider_CTRL_CMPMODE2_SHIFT)
#define Divider_DEFAULT_COMPARE1_MODE    (1u << Divider_CTRL_CMPMODE1_SHIFT)
#define Divider_INIT_DEAD_TIME           1u


/********************************
*         Registers
******************************** */

#if (Divider_UsingFixedFunction)
   #define Divider_PERIOD_LSB          (*(reg16 *) Divider_PWMHW__PER0)
   #define Divider_PERIOD_LSB_PTR      ( (reg16 *) Divider_PWMHW__PER0)
   #define Divider_COMPARE1_LSB        (*(reg16 *) Divider_PWMHW__CNT_CMP0)
   #define Divider_COMPARE1_LSB_PTR    ( (reg16 *) Divider_PWMHW__CNT_CMP0)
   #define Divider_COMPARE2_LSB        0x00u
   #define Divider_COMPARE2_LSB_PTR    0x00u
   #define Divider_COUNTER_LSB         (*(reg16 *) Divider_PWMHW__CNT_CMP0)
   #define Divider_COUNTER_LSB_PTR     ( (reg16 *) Divider_PWMHW__CNT_CMP0)
   #define Divider_CAPTURE_LSB         (*(reg16 *) Divider_PWMHW__CAP0)
   #define Divider_CAPTURE_LSB_PTR     ( (reg16 *) Divider_PWMHW__CAP0)
   #define Divider_RT1                 (*(reg8 *)  Divider_PWMHW__RT1)
   #define Divider_RT1_PTR             ( (reg8 *)  Divider_PWMHW__RT1)
      
#else
   #if(Divider_PWMModeIsCenterAligned)
       #define Divider_PERIOD_LSB      (*(reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__D1_REG)
       #define Divider_PERIOD_LSB_PTR   ((reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__D1_REG)
   #else
       #define Divider_PERIOD_LSB      (*(reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__F0_REG)
       #define Divider_PERIOD_LSB_PTR   ((reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__F0_REG)
   #endif
   #define Divider_COMPARE1_LSB    (*(reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__D0_REG)
   #define Divider_COMPARE1_LSB_PTR ((reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__D0_REG)
   #define Divider_COMPARE2_LSB    (*(reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__D1_REG)
   #define Divider_COMPARE2_LSB_PTR ((reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__D1_REG)
   #define Divider_COUNTERCAP_LSB   *(reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__A1_REG)
   #define Divider_COUNTERCAP_LSB_PTR ((reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__A1_REG)
   #define Divider_COUNTER_LSB     (*(reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__A0_REG)
   #define Divider_COUNTER_LSB_PTR  ((reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__A0_REG)
   #define Divider_CAPTURE_LSB     (*(reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__F1_REG)
   #define Divider_CAPTURE_LSB_PTR  ((reg16 *) Divider_PWMUDB_sP16_pwmdp_u0__F1_REG)
   #define Divider_AUX_CONTROLDP0      (*(reg8 *) Divider_PWMUDB_sP16_pwmdp_u0__DP_AUX_CTL_REG)
   #define Divider_AUX_CONTROLDP0_PTR  ((reg8 *) Divider_PWMUDB_sP16_pwmdp_u0__DP_AUX_CTL_REG)
   #if (Divider_Resolution == 16)
       #define Divider_AUX_CONTROLDP1    (*(reg8 *) Divider_PWMUDB_sP16_pwmdp_u1__DP_AUX_CTL_REG)
       #define Divider_AUX_CONTROLDP1_PTR  ((reg8 *) Divider_PWMUDB_sP16_pwmdp_u1__DP_AUX_CTL_REG)
   #endif
#endif
   
#if(Divider_KillModeMinTime )
    #define Divider_KILLMODEMINTIME      (*(reg8 *) Divider_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define Divider_KILLMODEMINTIME_PTR   ((reg8 *) Divider_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif

#if(Divider_DeadBandMode == Divider__B_PWM__DBM_256_CLOCKS)
    #define Divider_DEADBAND_COUNT        (*(reg8 *) Divider_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define Divider_DEADBAND_COUNT_PTR     ((reg8 *) Divider_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define Divider_DEADBAND_LSB_PTR       ((reg8 *) Divider_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define Divider_DEADBAND_LSB          (*(reg8 *) Divider_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(Divider_DeadBandMode == Divider__B_PWM__DBM_2_4_CLOCKS)
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (Divider_UsingFixedFunction)
        #define Divider_DEADBAND_COUNT        (*(reg8 *) Divider_PWMHW__CFG0) 
        #define Divider_DEADBAND_COUNT_PTR     ((reg8 *) Divider_PWMHW__CFG0)
        #define Divider_DEADBAND_COUNT_MASK    (0x03u << Divider_DEADBAND_COUNT_SHIFT) 
        #define Divider_DEADBAND_COUNT_SHIFT   0x06u /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */ 
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define Divider_DEADBAND_COUNT        (*(reg8 *) Divider_PWMUDB_sDB3_SyncCtl_dbctrlreg__CONTROL_REG)
        #define Divider_DEADBAND_COUNT_PTR     ((reg8 *) Divider_PWMUDB_sDB3_SyncCtl_dbctrlreg__CONTROL_REG)
        #define Divider_DEADBAND_COUNT_MASK    (0x03u << Divider_DEADBAND_COUNT_SHIFT) 
        #define Divider_DEADBAND_COUNT_SHIFT   0x00u /* As defined by the verilog implementation of the Control Register */
    #endif
#endif



#if (Divider_UsingFixedFunction)
    #define Divider_STATUS                (*(reg8 *) Divider_PWMHW__SR0)
    #define Divider_STATUS_PTR            ((reg8 *) Divider_PWMHW__SR0)
    #define Divider_STATUS_MASK           (*(reg8 *) Divider_PWMHW__SR0)
    #define Divider_STATUS_MASK_PTR       ((reg8 *) Divider_PWMHW__SR0)
    #define Divider_CONTROL               (*(reg8 *) Divider_PWMHW__CFG0)
    #define Divider_CONTROL_PTR           ((reg8 *) Divider_PWMHW__CFG0)    
    #define Divider_CONTROL2              (*(reg8 *) Divider_PWMHW__CFG1)    
    #if(Divider_PSOC3_ES3 || Divider_PSOC5_ES2)
        #define Divider_CONTROL3              (*(reg8 *) Divider_PWMHW__CFG2)
    #endif
    #define Divider_GLOBAL_ENABLE         (*(reg8 *) Divider_PWMHW__PM_ACT_CFG)
    #define Divider_GLOBAL_ENABLE_PTR       ( (reg8 *) Divider_PWMHW__PM_ACT_CFG)
    #define Divider_GLOBAL_STBY_ENABLE      (*(reg8 *) Divider_PWMHW__PM_STBY_CFG)
    #define Divider_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) Divider_PWMHW__PM_STBY_CFG)
  
  
    /***********************************
    *          Constants
    ***********************************/
    /* Fixed Function Block Chosen */
    #define Divider_BLOCK_EN_MASK          Divider_PWMHW__PM_ACT_MSK
    #define Divider_BLOCK_STBY_EN_MASK     Divider_PWMHW__PM_STBY_MSK 
    /* Control Register definitions */
    #define Divider_CTRL_ENABLE_SHIFT      0x00u
    
    #if(Divider_PSOC3_ES2 || Divider_PSOC5_ES1)
        #define Divider_CTRL_CMPMODE1_SHIFT    0x01u   /* As defined by Register map as MODE_CFG bits in CFG1*/
    #endif
    #if(Divider_PSOC3_ES3 || Divider_PSOC5_ES2)
        #define Divider_CTRL_CMPMODE1_SHIFT    0x04u  /* As defined by Register map as MODE_CFG bits in CFG2*/
    #endif
    
    #define Divider_CTRL_DEAD_TIME_SHIFT   0x06u   /* As defined by Register map */
    /* Fixed Function Block Only CFG register bit definitions */
    #define Divider_CFG0_MODE              0x02u   /*  Set to compare mode */
    //#define Divider_CFG0_ENABLE            0x01u   /* Enable the block to run */
    #define Divider_CFG0_DB                0x20u   /* As defined by Register map as DB bit in CFG0 */

    /* Control Register Bit Masks */
    #define Divider_CTRL_ENABLE            (0x01u << Divider_CTRL_ENABLE_SHIFT)
    #define Divider_CTRL_RESET             (0x01u << Divider_CTRL_RESET_SHIFT)
    #define Divider_CTRL_CMPMODE2_MASK     (0x07u << Divider_CTRL_CMPMODE2_SHIFT)
    #if(Divider_PSOC3_ES2 || Divider_PSOC5_ES1)
        #define Divider_CTRL_CMPMODE1_MASK     (0x07u << Divider_CTRL_CMPMODE1_SHIFT)
    #endif
    #if(Divider_PSOC3_ES3 || Divider_PSOC5_ES2)
        #define Divider_CTRL_CMPMODE1_MASK     (0x07u << Divider_CTRL_CMPMODE1_SHIFT)
    #endif
    
    /* Control2 Register Bit Masks */
    #define Divider_CTRL2_IRQ_SEL_SHIFT    0x00u       /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define Divider_CTRL2_IRQ_SEL          (0x01u << Divider_CTRL2_IRQ_SEL_SHIFT)  
    
    /* Status Register Bit Locations */
    #define Divider_STATUS_TC_SHIFT            0x07u   /* As defined by Register map as TC in SR0 */
    #define Divider_STATUS_CMP1_SHIFT          0x06u   /* As defined by the Register map as CAP_CMP in SR0 */
    
    /* Status Register Interrupt Enable Bit Locations */
    #define Divider_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)    
    #define Divider_STATUS_TC_INT_EN_MASK_SHIFT            (Divider_STATUS_TC_SHIFT - 4)
    #define Divider_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)  
    #define Divider_STATUS_CMP1_INT_EN_MASK_SHIFT          (Divider_STATUS_CMP1_SHIFT - 4)
    
    /* Status Register Bit Masks */
    #define Divider_STATUS_TC              (0x01u << Divider_STATUS_TC_SHIFT)
    #define Divider_STATUS_CMP1            (0x01u << Divider_STATUS_CMP1_SHIFT)
    
    /* Status Register Interrupt Bit Masks*/
    #define Divider_STATUS_TC_INT_EN_MASK              (Divider_STATUS_TC >> 4)
    #define Divider_STATUS_CMP1_INT_EN_MASK            (Divider_STATUS_CMP1 >> 4)
    
    /*RT1 Synch Constants: Applicable for PSoC3 ES2/PSoC3 ES3 PSoC5 ES2*/
    #define Divider_RT1_SHIFT              0x04u
    #define Divider_RT1_MASK               (0x03u << Divider_RT1_SHIFT)  /* Sync TC and CMP bit masks */
    #define Divider_SYNC                   (0x03u << Divider_RT1_SHIFT)
    #define Divider_SYNCDSI_SHIFT          0x00u
    #define Divider_SYNCDSI_MASK           (0x0Fu << Divider_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    #define Divider_SYNCDSI_EN             (0x0Fu << Divider_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    

#else
    #define Divider_STATUS                (*(reg8 *) Divider_PWMUDB_sSTSReg_rstSts_stsreg__STATUS_REG )
    #define Divider_STATUS_PTR            ((reg8 *) Divider_PWMUDB_sSTSReg_rstSts_stsreg__STATUS_REG )
    #define Divider_STATUS_MASK           (*(reg8 *) Divider_PWMUDB_sSTSReg_rstSts_stsreg__MASK_REG)
    #define Divider_STATUS_MASK_PTR       ((reg8 *) Divider_PWMUDB_sSTSReg_rstSts_stsreg__MASK_REG)
    #define Divider_STATUS_AUX_CTRL       (*(reg8 *) Divider_PWMUDB_sSTSReg_rstSts_stsreg__STATUS_AUX_CTL_REG)
    #define Divider_CONTROL               (*(reg8 *) Divider_PWMUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG)
    #define Divider_CONTROL_PTR           ((reg8 *) Divider_PWMUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG)
    
    
    /***********************************
    *          Constants
    ***********************************/
    /* Control Register definitions */
    #define Divider_CTRL_ENABLE_SHIFT      0x07u
    #define Divider_CTRL_RESET_SHIFT       0x06u
    #define Divider_CTRL_CMPMODE2_SHIFT    0x03u
    #define Divider_CTRL_CMPMODE1_SHIFT    0x00u
    #define Divider_CTRL_DEAD_TIME_SHIFT   0x00u   /* No Shift Needed for UDB block */
    /* Control Register Bit Masks */
    #define Divider_CTRL_ENABLE            (0x01u << Divider_CTRL_ENABLE_SHIFT)
    #define Divider_CTRL_RESET             (0x01u << Divider_CTRL_RESET_SHIFT)
    #define Divider_CTRL_CMPMODE2_MASK     (0x07u << Divider_CTRL_CMPMODE2_SHIFT)
    #define Divider_CTRL_CMPMODE1_MASK     (0x07u << Divider_CTRL_CMPMODE1_SHIFT) 
    
    /* Status Register Bit Locations */
    #define Divider_STATUS_KILL_SHIFT          0x05u
    #define Divider_STATUS_FIFONEMPTY_SHIFT    0x04u
    #define Divider_STATUS_FIFOFULL_SHIFT      0x03u  
    #define Divider_STATUS_TC_SHIFT            0x02u
    #define Divider_STATUS_CMP2_SHIFT          0x01u
    #define Divider_STATUS_CMP1_SHIFT          0x00u
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define Divider_STATUS_KILL_INT_EN_MASK_SHIFT          Divider_STATUS_KILL_SHIFT          
    #define Divider_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    Divider_STATUS_FIFONEMPTY_SHIFT    
    #define Divider_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      Divider_STATUS_FIFOFULL_SHIFT        
    #define Divider_STATUS_TC_INT_EN_MASK_SHIFT            Divider_STATUS_TC_SHIFT            
    #define Divider_STATUS_CMP2_INT_EN_MASK_SHIFT          Divider_STATUS_CMP2_SHIFT          
    #define Divider_STATUS_CMP1_INT_EN_MASK_SHIFT          Divider_STATUS_CMP1_SHIFT   
    /* Status Register Bit Masks */
    #define Divider_STATUS_KILL            (0x00u << Divider_STATUS_KILL_SHIFT )
    #define Divider_STATUS_FIFOFULL        (0x01u << Divider_STATUS_FIFOFULL_SHIFT)
    #define Divider_STATUS_FIFONEMPTY      (0x01u << Divider_STATUS_FIFONEMPTY_SHIFT)
    #define Divider_STATUS_TC              (0x01u << Divider_STATUS_TC_SHIFT)
    #define Divider_STATUS_CMP2            (0x01u << Divider_STATUS_CMP2_SHIFT) 
    #define Divider_STATUS_CMP1            (0x01u << Divider_STATUS_CMP1_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define Divider_STATUS_KILL_INT_EN_MASK            Divider_STATUS_KILL
    #define Divider_STATUS_FIFOFULL_INT_EN_MASK        Divider_STATUS_FIFOFULL
    #define Divider_STATUS_FIFONEMPTY_INT_EN_MASK      Divider_STATUS_FIFONEMPTY
    #define Divider_STATUS_TC_INT_EN_MASK              Divider_STATUS_TC
    #define Divider_STATUS_CMP2_INT_EN_MASK            Divider_STATUS_CMP2
    #define Divider_STATUS_CMP1_INT_EN_MASK            Divider_STATUS_CMP1
                                                          
    /* Datapath Auxillary Control Register definitions */
    #define Divider_AUX_CTRL_FIFO0_CLR     0x01u
    #define Divider_AUX_CTRL_FIFO1_CLR     0x02u
    #define Divider_AUX_CTRL_FIFO0_LVL     0x04u
    #define Divider_AUX_CTRL_FIFO1_LVL     0x08u
    #define Divider_STATUS_ACTL_INT_EN_MASK  0x10u /* As defined for the ACTL Register */
#endif /* Divider_UsingFixedFunction */

#endif  /* CY_PWM_Divider_H */
