/*******************************************************************************
* File Name: LCD_CustChars.c
* Version 1.50
*
* Description:
*  This file provides the source code for the Character LCD custom character
*  API.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "LCD.h"


uint8 const CYCODE LCD_customFonts[] = \
{
    /* Character LCD_CUSTOM_0   */
        0x00,    0x00,    0x00,    0x0A,    0x15,    0x00,    0x00,    0x00, \
    /* Character LCD_CUSTOM_1   */
        0x00,    0x00,    0x00,    0x00,    0x1F,    0x00,    0x00,    0x00, \
    /* Character LCD_CUSTOM_2   */
        0x00,    0x00,    0x00,    0x1F,    0x11,    0x1F,    0x00,    0x00, \
    /* Character LCD_CUSTOM_3   */
        0x1F,    0x11,    0x1F,    0x00,    0x00,    0x00,    0x0A,    0x15, \
    /* Character LCD_CUSTOM_4   */
        0x00,    0x03,    0x02,    0x02,    0x1E,    0x02,    0x03,    0x00, \
    /* Character LCD_CUSTOM_5   */
        0x00,    0x18,    0x08,    0x08,    0x0F,    0x08,    0x18,    0x00, \
    /* Character LCD_CUSTOM_6   */
        0x0E,    0x11,    0x11,    0x1F,    0x11,    0x11,    0x0E,    0x00, \
    /* Character LCD_CUSTOM_7   */
        0x11,    0x1F,    0x13,    0x15,    0x15,    0x19,    0x1F,    0x11 \
 };


/*******************************************************************************
* Function Name: LCD_LoadCustomFonts
********************************************************************************
*
* Summary:
*  Loads 8 custom font characters into the LCD Module for use.  Cannot use
*  characters from two different font sets at once, but font sets can be
*  switched out during runtime.
*
* Parameters:
*  customData:  pointer to a constant array of 64 bytes representing 8 custom
*               font characters.
* Return:
*  None.
*
* Theory:
*  Prior to using this function user need to import the pointer to custom
*  font array to your project by writting the following in the source code file 
*  where custom font will be used: 
*       extern uint8 const CYCODE LCD_Char_customFonts[];
*  This function is not automatically called by the Start() routine and must be
*  called manually by the user. 
*
*******************************************************************************/
void LCD_LoadCustomFonts(const uint8* customData) 
{
    uint8 indexU8;

    LCD_IsReady();
    
    /* Set starting address in the LCD Module.
    * Optionally: Read the current address to restore at a later time.
    */
    LCD_WriteControl(LCD_CGRAM_0);

    /* Load in the 64 bytes of CustomChar Data */
    for(indexU8 = 0u; indexU8 < LCD_CUSTOM_CHAR_SET_LEN; indexU8++)
    {
        LCD_WriteData(customData[indexU8]);
    }

    LCD_IsReady();
    LCD_WriteControl(LCD_DDRAM_0);
}


/* [] END OF FILE */
