/*******************************************************************************
* File Name: TIA.c
* Version 1.10
*
* Description:
*   This file provides the source code to the API for the OpAmp (Analog Buffer) 
*   User Module.
*
* NOTE:
* 
*
*******************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/




#include "cytypes.h"
#include "TIA.h"

uint8  TIA_initVar = 0;

/*******************************************************************************
* Funciton Name:   TIA_Start
********************************************************************************
*
* Summary:
*  The start function initializes the Analog Buffer with the default values, and 
*  sets the power to the given level.  A power level of 0, is the same as 
*  executing the stop function.
*
* Parameters: 
*
* Return:  
*    (void)
*
* Theory:
*
* Side Effects:
*
**********************************************************************************/
void TIA_Start(void) 
{
   if(TIA_initVar == 0)
   {
      TIA_initVar = 1;
      TIA_SetPower(TIA_DEFAULT_POWER);

      /* Set follower mode if selected */
      TIA_SW |= TIA_DEFAULT_MODE;
   }
	
	/*Enable negative charge pumps in ANIF*/
 	TIA_PUMP_CR1  |= (TIA_PUMP_CR1_CLKSEL | TIA_PUMP_CR1_FORCE );
	
	/* Enable power to buffer */
   TIA_PWRMGR |= TIA_ACT_PWR_EN;
   
}


/*******************************************************************************
* Function Name: TIA_Stop
********************************************************************************
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:  
*   (void)
*
* Return:  
*   (void)
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void TIA_Stop(void)
{
	/*Disable negative charge pumps for ANIF only if the one ABuf is turned ON*/
   	if(TIA_PWRMGR == TIA_ACT_PWR_EN)
   	{
	    TIA_PUMP_CR1 &= ~(TIA_PUMP_CR1_CLKSEL | TIA_PUMP_CR1_FORCE );
	}
	
	/* Disable power to buffer */
	TIA_PWRMGR &= ~TIA_ACT_PWR_EN;
		
}

/*******************************************************************************
* Funciton Name:   TIA_SetPower
********************************************************************************
*
* Summary:
*  Sets power level of Analog buffer.
*
* Parameters: 
*    power:   Sets power level between low (1) and high power (3).
*
* Return:  
*    (void)
*
* Theory:
*
* Side Effects:
*
**********************************************************************************/
void TIA_SetPower(uint8 power) 
{
      TIA_CR &= ~TIA_PWR_MASK;             /* Clear power setting  */
      TIA_CR |= ( power & TIA_PWR_MASK);   /* Set device power     */
}
/* [] END OF FILE */


