/*******************************************************************************
* File Name: TIA.h  
* Version 1.10
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the OpAmp (Analog Buffer) User Module.
*
*   Note:
*     
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/




#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_OPAMP_TIA_H) 
#define CY_OPAMP_TIA_H 

/**************************************
*        Function Prototypes 
**************************************/

void    TIA_Start(void);
void    TIA_Stop(void);
void    TIA_SetPower(uint8 power);


/**************************************
*           API Constants        
**************************************/

/* Power constants for SetPower() function */
#define TIA_LOWPOWER    0x01u
#define TIA_MEDPOWER    0x02u
#define TIA_HIGHPOWER   0x03u


/**************************************
*           Parameter Defaults        
**************************************/

#define TIA_DEFAULT_POWER    3 
#define TIA_DEFAULT_MODE     0 

/**************************************
*       Register Constants        
**************************************/

/* CX Analog Buffer Input Selection Register */

/* Power mode defines.                  */
#define TIA_PWR_MASK    0x03u 
#define TIA_PWR_SLOW    0x01u
#define TIA_PWR_MEDIUM  0x02u
#define TIA_PWR_FAST    0x03u

/* MX Analog Buffer Input Selection Register */

/* Bit Field  MX_VN                     */
#define TIA_MX_VN_MASK  0x30u 
#define TIA_MX_VN_NC    0x00u 
#define TIA_MX_VN_AG4   0x20u 
#define TIA_MX_VN_AG6   0x30u 

/* Bit Field  MX_VP                     */
#define TIA_MX_VP_MASK  0x0Fu 
#define TIA_MX_VP_NC    0x00u 
#define TIA_MX_VP_VREF  0x07u 
#define TIA_MX_VP_AG4   0x08u 
#define TIA_MX_VP_AG5   0x09u 
#define TIA_MX_VP_AG6   0x0Au 
#define TIA_MX_VP_AG7   0x08u 
#define TIA_MX_VP_ABUS0 0x0Cu 
#define TIA_MX_VP_ABUS1 0x0Du 
#define TIA_MX_VP_ABUS2 0x0Eu 
#define TIA_MX_VP_ABUS3 0x0Fu 

/* SW Analog Buffer Routing Switch Reg  */

/* Bit Field  SW                        */
#define TIA_SW_MASK     0x07u 
#define TIA_SW_SWINP    0x04u  /* Enable positive input */
#define TIA_SW_SWINN    0x02u  /* Enable negative input */
#define TIA_SW_SWFOL    0x01u  /* Enable follower mode  */

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#define TIA_ACT_PWR_EN   TIA_ABuf__PM_ACT_MSK /* Power enable mask */

/***********************************************/
/* ANIF.PUMP.CR1 Pump Configuration Register 1 */
/***********************************************/
#define TIA_PUMP_CR1  (* (reg8 *) CYDEV_ANAIF_CFG_PUMP_CR1)

#define TIA_PUMP_CR1_CLKSEL  0x40
#define TIA_PUMP_CR1_FORCE   0x20
#define TIA_PUMP_CR1_AUTO    0x10

/**************************************
*             Registers        
**************************************/

#define TIA_CR    	(* (reg8 *) TIA_ABuf__CR )
#define TIA_MX    	(* (reg8 *) TIA_ABuf__MX )
#define TIA_SW    	(* (reg8 *) TIA_ABuf__SW )
#define TIA_PWRMGR  (* (reg8 *) TIA_ABuf__PM_ACT_CFG )  /* Power manager */

#endif /* CY_OPAMP_TIA_H */

/* [] END OF FILE */
