/*******************************************************************************
* Copyright 2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

/* This header exports the configuration method(s) defined by this file. */
#include <cyfitter_cfg.h>

/* This header includes all of the necessary type definitions. */
#include <cytypes.h>

/* Standard system includes */
#if !defined(__ARMCC_VERSION)
#include <string.h>
#endif

/* This header contains all of the macros necessary for accessing registers on the device */
#include <cydevice.h>

/* This header contains all of the macros defined based on the users choices in the System DWR as well as instance
   based macros for register access. */
#include <cyfitter.h>

/* This header contains functions needed to enable the digital array */
#include <CyLib.h>

/* The section below contains all of the data used to initialize the device. */
#include <CyDmac.h>

#if defined(__C51__) || defined(__CX51__)
#define CYCODE code
#define CYDATA data
#define CYXDATA xdata
#define CYFAR far
extern void cymemzero(void CYFAR *addr, uint16 size);
extern void cyconfigcpy(uint16 size, const void CYFAR *src, void CYFAR *dest) small;
extern void cyconfigcpycode(uint16 size, const void CYCODE *src, void CYFAR *dest);
#define CYMEMZERO(a,c) cymemzero((a),(c))
#define CYCONFIGCPY(d,s,c) cyconfigcpy((c),(s),(d))
#define CYCONFIGCPYCODE(d,s,c) cyconfigcpycode((c),(s),(d))
#else
#define CYCODE
#define CYDATA
#define CYXDATA
#define CYFAR
#define CYMEMZERO(a,c) cymemset((a),0,(c))
#define CYCONFIGCPY(d,s,c) cymemcpy((d),(s),(c))
#define CYCONFIGCPYCODE(d,s,c) cymemcpy((d),(s),(c))
#endif

#if defined(__GNUC__)
#pragma GCC diagnostic ignored "-Wpointer-to-int-cast"
#endif
#if defined(__GNUC__) || defined(__ARMCC_VERSION)
#define CYPACKED __attribute__ ((packed))
#else
#define CYPACKED
#endif

#define CYDATADECL(name) const uint8 CYCODE name

typedef struct {
	void CYFAR *address;
	uint16 size;
} CYPACKED cfg_memset_t;

typedef struct {
	void CYFAR *dest;
	const void CYCODE *src;
	uint16 size;
} CYPACKED cfg_memcpy_t;

#define CFG_MEMSET_COUNT (sizeof(cfg_memset_list)/sizeof(*cfg_memset_list))
static const cfg_memset_t CYCODE cfg_memset_list [] = {
	/* address, size */
	{(void CYFAR *)(CYDEV_TMR0_CFG0), 11},
	{(void CYFAR *)(CYDEV_IO_PRT_PRT1_DR), 16},
	{(void CYFAR *)(CYDEV_IO_PRT_PRT4_DR), 16},
	{(void CYFAR *)(CYDEV_IO_PRT_PRT6_DR), 16},
	{(void CYFAR *)(CYDEV_IO_PRT_PRT15_DR), 16},
	{(void CYFAR *)(CYDEV_UCFG_B0_P0_U0_BASE), 4096},
	{(void CYFAR *)(CYDEV_UCFG_B1_P2_U0_BASE), 2048},
	{(void CYFAR *)(CYDEV_UCFG_DSI0_BASE), 2560},
	{(void CYFAR *)(CYDEV_UCFG_DSI12_BASE), 512},
};

CYDATADECL(cfg_byte_table) [] = {
	0x14,
	0x01, 0x4F, 0x00, 0x40, /* Base address 0x40004F00 */
	/* CYDEV_TMR0_CFG0 */
	0x09, 0x36, 
	0x02, 0x52, 0x00, 0x40, /* Base address 0x40005200 */
	/* CYDEV_PRTDSI_PRT12_BASE */
	0x61, 0x10, 0x64, 0x08, 
	0x02, 0x5A, 0x00, 0x40, /* Base address 0x40005A00 */
	/* CYDEV_ANAIF_RT_SC0_SW0 */
	0x0B, 0x04, 0x0C, 0x04, 
	0x02, 0x03, 0x01, 0x40, /* Base address 0x40010300 */
	/* CYDEV_UCFG_B0_P1_ROUTE_BASE + 0x00000080 */
	0xA5, 0x20, 0xB1, 0x20, 
	0x17, 0x04, 0x01, 0x40, /* Base address 0x40010400 */
	/* CYDEV_UCFG_B0_P2_U1_BASE */
	0x81, 0x02, 0x82, 0x04, 0x8C, 0x02, 0x8E, 0x04, 0x8F, 0x02, 0x96, 0x0B, 0x9C, 0x08, 0xAB, 0x01, 
	0xB0, 0x08, 0xB1, 0x01, 0xB3, 0x01, 0xB4, 0x06, 0xB6, 0x01, 0xB7, 0x02, 0xB9, 0x20, 0xBA, 0x0C, 
	0xBB, 0x0A, 0xBE, 0x11, 0xBF, 0x50, 0xD8, 0x09, 0xD9, 0x09, 0xDB, 0x04, 0xDC, 0x99, 
	0x18, 0x05, 0x01, 0x40, /* Base address 0x40010500 */
	/* CYDEV_UCFG_B0_P2_ROUTE_BASE */
	0x04, 0x01, 0x07, 0x01, 0x0D, 0x88, 0x1C, 0x01, 0x1D, 0x20, 0x1F, 0x09, 0x24, 0x40, 0x25, 0x08, 
	0x27, 0x0A, 0x2F, 0x08, 0x3D, 0x02, 0x3F, 0x40, 0x6F, 0x01, 0x7D, 0x20, 
	/* CYDEV_UCFG_B0_P2_ROUTE_BASE + 0x00000080 */
	0x8B, 0x08, 0x8F, 0x02, 0xA5, 0x20, 0xC0, 0x90, 0xC2, 0xA0, 0xCA, 0x20, 0xCE, 0x90, 0xDE, 0x20, 
	0xE2, 0x10, 0xE6, 0x80, 
	0x06, 0x06, 0x01, 0x40, /* Base address 0x40010600 */
	/* CYDEV_UCFG_B0_P3_U0_BASE */
	0x07, 0x02, 0x0F, 0x01, 0x31, 0x02, 0x37, 0x01, 0x59, 0x04, 0x5C, 0x90, 
	0x0B, 0x07, 0x01, 0x40, /* Base address 0x40010700 */
	/* CYDEV_UCFG_B0_P3_ROUTE_BASE */
	0x25, 0x81, 0x3C, 0x44, 0x65, 0x01, 0x67, 0x40, 
	/* CYDEV_UCFG_B0_P3_ROUTE_BASE + 0x00000080 */
	0x90, 0x40, 0x97, 0x40, 0xA5, 0x81, 0xA9, 0x10, 0xB7, 0x01, 0xCE, 0x50, 0xEA, 0x40, 
	0x01, 0x0B, 0x01, 0x40, /* Base address 0x40010B00 */
	/* CYDEV_UCFG_B0_P5_ROUTE_BASE + 0x00000080 */
	0xE4, 0x80, 
	0x01, 0x0D, 0x01, 0x40, /* Base address 0x40010D00 */
	/* CYDEV_UCFG_B0_P6_ROUTE_BASE + 0x00000080 */
	0xEC, 0x80, 
	0x02, 0x17, 0x01, 0x40, /* Base address 0x40011700 */
	/* CYDEV_UCFG_B1_P3_ROUTE_BASE + 0x00000080 */
	0xA8, 0x04, 0xA9, 0x01, 
	0x02, 0x41, 0x01, 0x40, /* Base address 0x40014100 */
	/* CYDEV_UCFG_DSI1_BASE */
	0x58, 0x04, 
	/* CYDEV_UCFG_DSI1_BASE + 0x00000080 */
	0xD6, 0x40, 
	0x0D, 0x42, 0x01, 0x40, /* Base address 0x40014200 */
	/* CYDEV_UCFG_DSI2_BASE */
	0x13, 0x80, 0x31, 0x01, 0x40, 0x02, 0x63, 0x08, 0x70, 0x01, 0x71, 0x01, 
	/* CYDEV_UCFG_DSI2_BASE + 0x00000080 */
	0x88, 0x04, 0x8C, 0x02, 0x9C, 0x04, 0xC4, 0x40, 0xCC, 0x40, 0xD0, 0x10, 0xD8, 0x40, 
	0x07, 0x43, 0x01, 0x40, /* Base address 0x40014300 */
	/* CYDEV_UCFG_DSI3_BASE */
	0x17, 0x08, 
	/* CYDEV_UCFG_DSI3_BASE + 0x00000080 */
	0xAB, 0x80, 0xB4, 0x01, 0xB7, 0x04, 0xC2, 0x10, 0xC4, 0x20, 0xE8, 0x80, 
	0x04, 0x44, 0x01, 0x40, /* Base address 0x40014400 */
	/* CYDEV_UCFG_DSI4_BASE */
	0x30, 0x04, 0x74, 0x02, 
	/* CYDEV_UCFG_DSI4_BASE + 0x00000080 */
	0xCC, 0x02, 0xDE, 0x04, 
	0x03, 0x45, 0x01, 0x40, /* Base address 0x40014500 */
	/* CYDEV_UCFG_DSI5_BASE + 0x00000080 */
	0xA4, 0x02, 0xB0, 0x04, 0xEC, 0x01, 
	0x03, 0x46, 0x01, 0x40, /* Base address 0x40014600 */
	/* CYDEV_UCFG_DSI6_BASE + 0x00000080 */
	0x88, 0x02, 0xA4, 0x02, 0xE4, 0x01, 
	0x02, 0x48, 0x01, 0x40, /* Base address 0x40014800 */
	/* CYDEV_UCFG_DSI8_BASE + 0x00000080 */
	0xAB, 0x08, 0xE8, 0x20, 
	0x02, 0x50, 0x01, 0x40, /* Base address 0x40015000 */
	/* CYDEV_UCFG_BCTL0_MDCLK_EN */
	0x01, 0x01, 0x0B, 0x01, 
	0x02, 0x51, 0x01, 0x40, /* Base address 0x40015100 */
	/* CYDEV_IDMUX_IRQ_CTL0 */
	0x03, 0x03, 
	/* CYDEV_IDMUX_DRQ_CTL0 */
	0x12, 0x20, 
};
/* BYTES: 307 */

/* IOPINS0_0 Address: CYDEV_IO_PRT_PRT0_DM0 Size (bytes): 8 */
static CYDATADECL(BS_IOPINS0_0_VAL) [] = {
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x5A, 0x00};

/* IOPINS0_7 Address: CYDEV_IO_PRT_PRT12_DR Size (bytes): 10 */
static CYDATADECL(BS_IOPINS0_7_VAL) [] = {
	0x08, 0x00, 0x08, 0x18, 0x18, 0x00, 0x10, 0x00, 0x00, 0x00};

/* IOPINS0_2 Address: CYDEV_IO_PRT_PRT2_DM0 Size (bytes): 8 */
static CYDATADECL(BS_IOPINS0_2_VAL) [] = {
	0x00, 0x7F, 0x7F, 0x00, 0x00, 0x00, 0x00, 0x00};

/* IOPINS0_3 Address: CYDEV_IO_PRT_PRT3_DM0 Size (bytes): 8 */
static CYDATADECL(BS_IOPINS0_3_VAL) [] = {
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC9, 0x00};

/* IOPINS0_5 Address: CYDEV_IO_PRT_PRT5_DM0 Size (bytes): 8 */
static CYDATADECL(BS_IOPINS0_5_VAL) [] = {
	0x00, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00};

/* PHUB_CFGMEM10 Address: CYDEV_PHUB_CFGMEM10_CFG0 Size (bytes): 4 */
static CYDATADECL(BS_PHUB_CFGMEM10_VAL) [] = {
	0x00, 0x0A, 0x00, 0x00};


#if defined(__C51__) || defined(__CX51__)
extern void cfg_write_bytes_code(void CYCODE *table);
extern void cfg_write_bytes(void CYFAR *table);
#else
/* For 32-bit little-endian architectures */
static void cfg_write_bytes32(void)
{
	const uint8 *tablePtr = cfg_byte_table;
	int recordCount = *tablePtr++;

	do
	{
		uint8 *base = *((uint8 **)tablePtr);	/* Read upper address and pair count */
		int pairCount = (int)base & 0x000000FF;
		base -= pairCount;
		tablePtr += sizeof(uint8 *);
		do
		{
			uint8 offset = *tablePtr++;			/* LSB of address */
			CY_SET_XTND_REG8(base + offset, *tablePtr++);
		}
		while (--pairCount);
	}
	while (--recordCount);
}
#endif

static void ClockSetup(void)
{
	uint32 CYDATA timeout;
	uint8 CYDATA pllLock;
	CY_SET_XTND_REG24((void CYFAR *)(CYDEV_CLKDIST_DCFG0_CFG0), 0x180007);
	CY_SET_XTND_REG24((void CYFAR *)(CYDEV_CLKDIST_ACFG0_CFG0), 0x180063);
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_SLOWCLK_ILO_CR0), 0x02);
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_CLKDIST_CR), 0x08);
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_FASTCLK_IMO_CR), 0x03);
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_MFGCFG_IMO_TR1), (CY_GET_XTND_REG8(CYDEV_FLSHID_BASE + 0x108)));
	CY_SET_XTND_REG16((void CYFAR *)(CYDEV_FASTCLK_PLL_P), 0x0242);
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_CLKDIST_CR), 0x08);
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_FASTCLK_PLL_CFG0), 0x51);
	pllLock = 0;
	for (timeout = 256; timeout && (pllLock != 0x03u); timeout--) { pllLock = 0x03u & ((pllLock << 1) | ((CY_GET_XTND_REG8(CYDEV_FASTCLK_PLL_SR) & 0x01u) >> 0)); }
	CY_SET_XTND_REG16((void CYFAR *)(CYDEV_CLKDIST_MSTR0), 0x0103);
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_CLKDIST_MSTR0), 0x00);
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_CLKDIST_BCFG0), 0x00);
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_CLKDIST_BCFG2), 0x48);
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_CLKDIST_LD), 0x02);

	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_PM_ACT_CFG2), ((CY_GET_XTND_REG8(CYDEV_PM_ACT_CFG2) | 0x01)));

	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_PM_ACT_CFG1), ((CY_GET_XTND_REG8(CYDEV_PM_ACT_CFG1) | 0x01)));
}

/* Analog API Functions */
void AnalogSetDefault(void)
{
	CY_SET_XTND_REG8(CYDEV_ANAIF_RT_SC0_SW0, 0x10);
	CY_SET_XTND_REG8(CYDEV_ANAIF_RT_SC0_SW4, 0x40);
	CY_SET_XTND_REG8(CYDEV_ANAIF_RT_SC0_SW8, 0x02);
	CY_SET_XTND_REG8(CYDEV_ANAIF_RT_DAC1_SW3, 0x80);
	CY_SET_XTND_REG8(CYDEV_ANAIF_RT_DAC3_SW0, 0x20);
	CY_SET_XTND_REG8(CYDEV_ANAIF_RT_DSM0_SW0, 0x02);
	CY_SET_XTND_REG8(CYDEV_ANAIF_RT_SAR0_SW0, 0x20);
	CY_SET_XTND_REG32(CYDEV_ANAIF_RT_ABUF0_MX, 0x01120201);
	CY_SET_XTND_REG8(CYDEV_ANAIF_RT_ABUF3_SW, 0x05);
	CY_SET_XTND_REG8(CYDEV_ANAIF_RT_BUS_SW0, 0x10);
	CY_SET_XTND_REG8(CYDEV_ANAIF_CFG_PUMP_CR0, 0x66);
	CY_SET_XTND_REG8(CYDEV_ANAIF_CFG_PUMP_CR1, 0x66);
}

#define CY_AMUX_UNUSED CYDEV_BOOST_SR
uint8 CYXDATA * const CYCODE Measure_Mux_CYAMUXSIDE_A__addrTable[] = {
	(uint8 CYXDATA *)CYDEV_IO_PRT_PRT0_AG, (uint8 CYXDATA *)CY_AMUX_UNUSED, 
	(uint8 CYXDATA *)CYDEV_IO_PRT_PRT0_AG, (uint8 CYXDATA *)CYDEV_ANAIF_RT_SAR0_SW0, 
};

const uint8 CYCODE Measure_Mux_CYAMUXSIDE_A__maskTable[] = {
	0x40, 0x00, 
	0x02, 0x40, 
};

void Measure_Mux_CYAMUXSIDE_A_Set(uint8 channel)
{
	if (channel >= 2)
		return;
	channel += channel;
	*Measure_Mux_CYAMUXSIDE_A__addrTable[channel] |= Measure_Mux_CYAMUXSIDE_A__maskTable[channel];
	channel++;
	*Measure_Mux_CYAMUXSIDE_A__addrTable[channel] |= Measure_Mux_CYAMUXSIDE_A__maskTable[channel];
}

void Measure_Mux_CYAMUXSIDE_A_Unset(uint8 channel)
{
	if (channel >= 2)
		return;
	channel += channel;
	*Measure_Mux_CYAMUXSIDE_A__addrTable[channel] &= ~Measure_Mux_CYAMUXSIDE_A__maskTable[channel];
	channel++;
	*Measure_Mux_CYAMUXSIDE_A__addrTable[channel] &= ~Measure_Mux_CYAMUXSIDE_A__maskTable[channel];
}

uint8 CYXDATA * const CYCODE Measure_Mux_CYAMUXSIDE_B__addrTable[] = {
	(uint8 CYXDATA *)CYDEV_ANAIF_RT_SC0_SW0, (uint8 CYXDATA *)CYDEV_ANAIF_RT_DSM0_SW4, 
	(uint8 CYXDATA *)CYDEV_IO_PRT_PRT0_AMUX, (uint8 CYXDATA *)CYDEV_ANAIF_RT_DSM0_SW3, 
};

const uint8 CYCODE Measure_Mux_CYAMUXSIDE_B__maskTable[] = {
	0x80, 0x80, 
	0x10, 0x10, 
};

void Measure_Mux_CYAMUXSIDE_B_Set(uint8 channel)
{
	if (channel >= 2)
		return;
	channel += channel;
	*Measure_Mux_CYAMUXSIDE_B__addrTable[channel] |= Measure_Mux_CYAMUXSIDE_B__maskTable[channel];
	channel++;
	*Measure_Mux_CYAMUXSIDE_B__addrTable[channel] |= Measure_Mux_CYAMUXSIDE_B__maskTable[channel];
}

void Measure_Mux_CYAMUXSIDE_B_Unset(uint8 channel)
{
	if (channel >= 2)
		return;
	channel += channel;
	*Measure_Mux_CYAMUXSIDE_B__addrTable[channel] &= ~Measure_Mux_CYAMUXSIDE_B__maskTable[channel];
	channel++;
	*Measure_Mux_CYAMUXSIDE_B__addrTable[channel] &= ~Measure_Mux_CYAMUXSIDE_B__maskTable[channel];
}


/* Digital routing enable Functions */
static void EnableDigitalRouting() {
	CY_SET_XTND_REG8(CYDEV_UCFG_BCTL0_BANK_CTL, CY_GET_XTND_REG8(CYDEV_UCFG_BCTL0_BANK_CTL) | 0x02);
	CY_SET_XTND_REG8(CYDEV_UCFG_BCTL1_BANK_CTL, CY_GET_XTND_REG8(CYDEV_UCFG_BCTL1_BANK_CTL) | 0x02);
}

/* This function is called by the start-up code for the selected device. */
void cyfitter_cfg(void)
{
	uint8 CYDATA i;

#ifdef CYGlobalIntDisable
	CYGlobalIntDisable;

#endif
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_CACHE_CC_CTL), ((CYDEV_INSTRUCT_CACHE_ENABLED) ? 0x40 : 0x41));
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_PHUB_CH0_BASIC_CFG), 0x00);
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_PHUB_CH1_BASIC_CFG), 0x00);

	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_ANAIF_CFG_MISC_CR0), 0x01);

	CY_SET_XTND_REG8(CYDEV_MFGCFG_MLOGIC_DBG_DBE, (CY_GET_XTND_REG8(CYDEV_MFGCFG_MLOGIC_DBG_DBE) | 0x01));
	for (i = 0; i < CFG_MEMSET_COUNT; i++)
	{
		const cfg_memset_t CYCODE * CYDATA ms = &cfg_memset_list[i];
		CYMEMZERO(ms->address, ms->size);
	}

	cfg_write_bytes32();

	CYCONFIGCPYCODE((void CYFAR *)(CYDEV_PHUB_CFGMEM10_CFG0), (void CYCODE *)(BS_PHUB_CFGMEM10_VAL), 4);
	/* BYTES WRITTEN: 4 */
	EnableDigitalRouting();

	CyEnableDigitalArray();

	CYCONFIGCPYCODE((void CYFAR *)(CYDEV_IO_PRT_PRT0_DM0), (void CYCODE *)(BS_IOPINS0_0_VAL), 8);
	CYCONFIGCPYCODE((void CYFAR *)(CYDEV_IO_PRT_PRT12_DR), (void CYCODE *)(BS_IOPINS0_7_VAL), 10);
	CYCONFIGCPYCODE((void CYFAR *)(CYDEV_IO_PRT_PRT2_DM0), (void CYCODE *)(BS_IOPINS0_2_VAL), 8);
	CYCONFIGCPYCODE((void CYFAR *)(CYDEV_IO_PRT_PRT3_DM0), (void CYCODE *)(BS_IOPINS0_3_VAL), 8);
	CYCONFIGCPYCODE((void CYFAR *)(CYDEV_IO_PRT_PRT5_DM0), (void CYCODE *)(BS_IOPINS0_5_VAL), 8);
	/* BYTES WRITTEN: 42 */

	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_CACHE_CC_CTL), ((CYDEV_INSTRUCT_CACHE_ENABLED) ? 0x00 : 0x01));
	ClockSetup();
	CY_SET_XTND_REG8((void CYFAR *)(CYDEV_CACHE_CC_CTL), ((CYDEV_INSTRUCT_CACHE_ENABLED) ? 0xC0 : 0xC1));

	AnalogSetDefault();
}

/* [] END OF FILE */
